Learn R Programming

TopKLists (version 1.0.2)

MC.ranks: MC based rank aggregation

Description

Compute aggregate ranks based on the transition matrix from the three Markov Chain algorithms.

Usage

MC.ranks(elements, trans, a, delta)

Arguments

elements
Unique elements of the union of all input lists - second element of the output list from function trans.matrix
trans
One of the three transition matrices build by function trans.matrix - 4 (5 or 6) elements of the output list from function trans.matrix
a
Tuning parameter to make sure Markov Chain with the transition matrix is ergodic; parameter value passed from MC.
delta
Convergence criterion for stationary distribution; parameter value passed from MC.

Value

  • A list with 3 components:
  • comp1Number of iterations to reach the stationary distribution
  • comp2The stationary distribution
  • comp3The rankings based on the stationary distribution

Details

Compute stationary distribution based on a Markov Chain transition matrix built with function trans.matrix.

References

Lin, S. (2010) Space oriented rank-based data integration. Statistical Applications in Genetics and Molecular Biology 9, Article 20.

See Also

MC, trans.matrix