Idata vector (see prepare.idata), the estimated truncation index $j_0=k+1$ (see compute.stream) for each pair of input lists, the overall top-k estimate (see j0.multi), and other objects with necessary plotting information for the aggmapcalculate.maxK(lists, L, d, v, threshold)aggmap as a consolidated objectaggmap)aggmap)aggmap)aggmapcompute.stream) for each pair of input lists and the associated delta'sCEMC, prepare.idataset.seed(1234)
data(breast)
truncated.lists = calculate.maxK(breast, d=6, v=10, L=3, threshold=50)
aggmap(truncated.lists)Run the code above in your browser using DataLab