Spearman's footrule is a measure for distance between ranked lists. It is given as the sum of absolute differences between ranks of two lists. Here a modified version is implemented that allows for comparing partial lists.
Usage
Spearman(rank.a, rank.b, k.a, k.b, n)
Arguments
rank.a
A single top-k list
rank.b
A vector of matrix form of top-k list(s) to be compared to the list a
k.a
Value of k for rank.a
k.b
Value of k for rank.b
n
Total number of objects, numbered from 1 to n
Value
Returns modified Spearman distance against a for each lists within b